{ config, pkgs, lib, ... }:

with lib;

{
  imports = [
    ../modules/wal.nix
  ];

  home.packages = with pkgs;
    let
      gn = pkgs.gnome3;
      evolution = pkgs.evolutionWithPlugins.override { plugins = [ pkgs.evolution pkgs.evolution-ews ]; };
    in [
      keybase-gui

      gn.gnome-tweaks
      gmrun
      mate.atril
      mate.caja
      libreoffice-fresh
      inkscape
      glimpse
      krita
      nyxt
      lagrange
      evolution
      thunderbird
      calibre

      openshot-qt
      blender
      asunder
      gn.cheese
      vlc
      v4l-utils
      handbrake
      darktable
      pavucontrol
      vorbis-tools
      audacity
      pulseaudio
      jack2
      cadence
      non
      blueman

      element-desktop
      signal-desktop
      slack
      teams
      tdesktop
      zoom-us
      postman

      wineFull
    ];

  home.file = {
    ".face".source = ../dotfiles/images/cat.jpg;
  };
  xdg.configFile = {
    "wofi".source = ../dotfiles/wofi;
    "kitty/sessions/default.conf".text = ''
      layout vertical
      cd ~
    '';
    "waybar".source = ../dotfiles/waybar;
  };

  home.activation = {
    updateFcCache = lib.hm.dag.entryAfter [ "writeBoundary" ] ''
      $DRY_RUN_CMD fc-cache -f
    '';
  };

  programs.wal = {
    enable = true;
    background = pkgs.fetchurl {
      # From Stefanie Buchanan's ArtStation: https://www.artstation.com/artwork/bK0kkn
      urls = [
        "https://cdnb.artstation.com/p/assets/images/images/029/712/149/large/stefanie-buchanan-img-2414.jpg"
        "http://bafybeiff7bjww2dicbqhfubiq67wma6qrjkkndk6s773glwiystzir2goe.ipfs.localhost:8080/"
        "https://bafybeiff7bjww2dicbqhfubiq67wma6qrjkkndk6s773glwiystzir2goe.ipfs.dweb.link/"
      ];
      name = "wallpaper.jpg";
      sha256 = "b6b9b88e10715e9e7dfd33dc80ecfff90fa58f0529e6f7c88f67f34991da57e0";
    };
    shell.enable = true;
    sway.enable = true;
  };

  gtk = {
    enable = true;

    theme.name = "Equilux";
    theme.package = pkgs.equilux-theme;
    font.name = "Fira Sans Condensed Regular 10";
    font.package = pkgs.fira;
    iconTheme.name = "Flat-Remix-Green-Dark";
    iconTheme.package = pkgs.flat-remix-icon-theme;

    gtk3.extraConfig = {
      gtk-xft-antialias = 1;
      gtk-xft-hinting = 1;
      gtk-xft-hintstyle = "hintmedium";
      gtk-xft-rgba = "rgb";
    };
  };

  programs.mako = {
    enable = true;
    defaultTimeout = 10000;
  };

  programs.waybar = {
    enable = true;
    systemd.enable = true;
  };

  services.gammastep = {
    enable = true;
    provider = "manual";
    latitude = 54.0;
    longitude = 1.0;
    tray = true;
  };

  programs.kitty = {
    enable = true;
    font.name = "Iosevka Medium";
    font.package = pkgs.iosevka;
    settings = {
      font_size = "11.0";

      allow_remote_control = true;
      listen_on = "unix:\${XDG_RUNTIME_DIR}/kitty.sock";

      enable_audio_bell = false;
      visual_bell_duration = "0.1";
    };
    extraConfig = strings.fileContents ../colours/gruvbox-kitty.conf;
  };

  programs.chromium.enable = true;
  programs.qutebrowser.enable = true;

  programs.obs-studio = {
    enable = true;
    plugins = with pkgs; [ obs-v4l2sink obs-wlrobs ];
  };

  programs.ncmpcpp.settings = { user_interface = "alternative"; };

  services.syncthing.enable = true;
}
