{ config, pkgs, lib, ... }:

{
  home.packages = with pkgs;
    let py = python38Packages;
    in [
      editorconfig-core-c
      black
      mypy
      haskell-language-server
      rust-analyzer
      py.python-language-server
      py.pyls-isort
      py.pyls-black
      py.pyls-mypy
    ];

  home.file = let
    chemacs2 = pkgs.fetchFromGitHub {
      owner = "plexus";
      repo = "chemacs2";
      # branch "master" on 2021-01-30
      rev = "30a20dbc2799e4ab2f8c509fdadcd90aa9845b5c";
      sha256 = "0ghry3v05y31vgpwr2hc4gzn8s6sr6fvqh88fsnj9448lrim38f9";
    };
    doom-emacs = pkgs.fetchFromGitHub {
      owner = "hlissner";
      repo = "doom-emacs";
      # branch "master" on 2021-01-30
      rev = "5acd41de3d10e0d6f3004970afa02c543f271760";
      sha256 = "0mllffr72nqkwky7kghdh36ajdj499s4mjp2wgq9zkqq6l05pgxp";
    };
    spacemacs = pkgs.fetchFromGitHub {
      owner = "syl20bnr";
      repo = "spacemacs";
      # branch "develop" on 2021-01-11
      rev = "b59be2b15efc87d6bfddacb59013a9dce58f2192";
      sha256 = "040llrrvaqs1kf5pkmyd0gglc5h402i3ja7kqx0njjbpiaanwvm4";
    };
  in {
    ".emacs.d" = {
      source = chemacs2;
      recursive = true;
    };
    ".emacs-profiles.el".text = ''
      (("spacemacs" . ((user-emacs-directory . "~/.emacs.spacemacs")))
       ("doom" .      ((user-emacs-directory . "~/.emacs.doom"))))
    '';

    ".emacs.doom" = {
      source = doom-emacs;
      recursive = true;
    };
    ".doom.d" = {
      source = ../dotfiles/doom;
      recursive = true;
      onChange = ''
        EMACSDIR=~/.emacs.doom $DRY_RUN_CMD ~/.emacs.doom/bin/doom sync -e
      '';
    };
    ".doom.d/snippets".source = ../dotfiles/emacs/snippets;

    ".emacs.spacemacs" = {
      source = spacemacs;
      recursive = true;
    };
    ".spacemacs".source = ../dotfiles/spacemacs;
    ".spacemacs.d/private" = {
      source = ../dotfiles/spacemacs-private;
      recursive = true;
    };
    ".spacemacs.d/private/snippets".source = ../dotfiles/emacs/snippets;

    ".local/share/applications/org-protocol.desktop".source = let
      org-protocol-desktop = pkgs.makeDesktopItem {
        name = "org-protocol";
        desktopName = "Emacs org-protocol handler";
        exec = "emacsclient %u";
        terminal = "false";
        categories = "System;";
        mimeType = "x-scheme-handler/org-protocol;";
      };
    in org-protocol-desktop + /share/applications/org-protocol.desktop;
  };
  programs.firefox.profiles.default.settings = {
    "network.protocol-handler.expose.org-protocol" = false;
  };

  programs.zsh.shellAliases = {
      e = "emacsclient -t"; # Terminal
      ew = "emacsclient -c"; # New window (and wait)
      en = "emacsclient -nc"; # New window (and return immediately)
      calc = "emacs -f full-calc -nw -q"; # Quick fullscreen calculator

      doom = "EMACSDIR=~/.emacs.doom ~/.emacs.doom/bin/doom";
  };

  programs.emacs.enable = true;

  services.gpg-agent.extraConfig = ''
    allow-emacs-pinentry
  '';
}
