{ config, pkgs, lib, ... }:

{
  imports = [
    ../bits/home-common.nix
    ../bits/zfs.nix
    ../bits/amdgpu.nix
    ../bits/foldingathome.nix
  ];

  boot.loader = {
    efi = {
      canTouchEfiVariables = false;
      efiSysMountPoint = "/boot/efi";
    };
    grub = {
      enable = true;
      efiSupport = true;
      efiInstallAsRemovable = false;
      device = "nodev";
      gfxmodeEfi = "2560x1440";
      extraConfig = ''
        set timeout=2;
        set timeout_style="menu";
      '';
    };
  };

  users.users.jez.uid = 1000;
  users.groups.jez.gid = 1000;

  networking.interfaces.enp39s0.useDHCP = true;

  networking.firewall.allowedTCPPorts = [
    6600 # mpd
    21   # ftp
    1313 # Hugo preview
  ];

  hardware.pulseaudio.daemon.config = {
    default-sample-rate = "192000";
    alternate-sample-rate = "96000";
    avoid-resampling = "yes";
  };

  services.vsftpd = {
    enable = true;
    localUsers = true;
    userlist = [ "jez" ];
    writeEnable = true;
  };
}
